
#THREE-LEVEL META-ANALYSIS EXAMPLE
#to clean the environment
rm(list=ls(all=TRUE))

#install packages 
install.packages()

#call packages from library
library("metafor")
library("esc")
library("ggplot2")
library(dmetar)

####THREE-LEVEL META-ANALYSIS ON EMOTIONAL OUTCOMES
# import data
library(readr)
anxietydataset <- read_csv("anxietydataset.csv")
# read dataset
MA_data <- read.csv("anxietydataset.csv")

head(MA_data)
#############################

#RQ: What is the association between paternal anxiety and offspring emotional outcomes?
#run three-level meta-analysis for RQ
emotional_outcomes <- rma.mv(yi = fisher_z, 
                             V = var_z, 
                             slab = author_year, 
                             data = MA_data, 
                             random = ~ 1 | sample_id/es_r_id, 
                             test = "t", 
                             method = "REML")
summary(emotional_outcomes)


convert_z2r(0.1479)
convert_z2r(0.0954)
convert_z2r(0.2005)

#HETEROGENEITY
#I^2
#IN OUR THREE-LEVEL MODEL, I^2 IS SPLIT IN TWO PARTS, ONE ATTRIBUTABLE TO THE 
#TRUE EFFECT SIZE DIFFERENCES WITHIN CLUSTERS, THE OTHER TO BETWEEN-CLUSTER VARIATION. 
#LEVEL 2 IS WTIHIN CLUSTERS 
#LEVEL 3 IS BETWEEN CLUSTERS
i2 <- var.comp(emotional_outcomes)
summary(i2)

plot(i2)

##FOREST PLOT for a visual summary
forest(emotional_outcomes)

#to learn more about forest plots for random-effects models m-a
?forest.rma

#to obtain a forest plot that reflects the nested structure of our data
###CREATE A FOREST PLOT TO SHOW ONLY AGGREGATED EFFECTS FOR EACH SAMPLE.
#The forest plot represents a meta-analysis of aggregated samples for readers' 
#ease and it is an approximate representation of the three-level meta-analysis
#reported in the text.

dat <- escalc(measure="ZCOR", yi=fisher_z, vi=var_z, 
              data=MA_data, slab=paste(sample_label, obs_id))
dat
V <- vcalc(var_z, cluster=sample_label, obs=obs_id, data=dat, rho=0.8)
res <- rma(yi,vi,data=dat)
res
agg <- aggregate(dat, cluster=sample_label, V=vcov(res, type="obs"), addk=TRUE)
agg
res <- rma(yi, vi, method="REML", data=agg, digits=3, slab=sample_label)
res



#forest plot
forest(res, mlab="Pooled Estimate", addpred=TRUE, header="Sample", 
       studylab="sample", ilab=ki, ilab.xpos=-2.7, cex=.89, order="obs", 
       xlim=c(-8,6), at=seq(-0.5,1.5,by=0.5), showweights=TRUE)
text(-2.7, res$k+2, "Number of Estimates", cex=.89, font=1.5)  
text(2.7, res$k+2, "Weight", cex=.89, font=1.5)  


